==> admin_scripts-0.3.13.tar.gz: admin_scripts-0.3.13/setup.py <==
#!/usr/bin/python
# -*- coding: utf-8 -*-

# Hive Administration Scripts
# Copyright (c) 2008-2016 Hive Solutions Lda.
#
# This file is part of Hive Administration Scripts.
#
# Hive Administration Scripts is free software: you can redistribute it and/or modify
# it under the terms of the Apache License as published by the Apache
# Foundation, either version 2.0 of the License, or (at your option) any
# later version.
#
# Hive Administration Scripts is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# Apache License for more details.
#
# You should have received a copy of the Apache License along with
# Hive Administration Scripts. If not, see <http://www.apache.org/licenses/>.

__author__ = "João Magalhães <joamag@hive.pt>"
""" The author(s) of the module """

__version__ = "1.0.0"
""" The version of the module """

__revision__ = "$LastChangedRevision$"
""" The revision number of the module """

__date__ = "$LastChangedDate$"
""" The last change date of the module """

__copyright__ = "Copyright (c) 2008-2016 Hive Solutions Lda."
""" The copyright for the module """

__license__ = "Apache License, Version 2.0"
""" The license for the module """

import os
import setuptools

setuptools.setup(
    name = "admin_scripts",
    version = "0.3.13",
    author = "Hive Solutions Lda.",
    author_email = "development@hive.pt",
    description = "Administration Scripts",
    license = "Apache License, Version 2.0",
    keywords = "scripts admin public",
    url = "http://admin_scripts.hive.pt",
    zip_safe = False,
    packages = [
        "admin_scripts",
        "admin_scripts.base",
        "admin_scripts.config",
        "admin_scripts.config.development",
        "admin_scripts.extra",
        "admin_scripts.test"
    ],
    test_suite = "admin_scripts.test",
    package_dir = {
        "" : os.path.normpath("src")
    },
    entry_points = {
        "console_scripts" : [
            "cleanup = admin_scripts.base.cleanup:run"
        ]
    },
    install_requires = [
        "legacy",
        "pep8",
        "jsbeautifier"
    ],
    classifiers = [
        "Development Status :: 5 - Production/Stable",
        "Topic :: Utilities",
        "License :: OSI Approved :: Apache Software License",
        "Operating System :: OS Independent",
        "Programming Language :: Python",
        "Programming Language :: Python :: 2.6",
        "Programming Language :: Python :: 2.7",
        "Programming Language :: Python :: 3.0",
        "Programming Language :: Python :: 3.1",
        "Programming Language :: Python :: 3.2",
        "Programming Language :: Python :: 3.3",
        "Programming Language :: Python :: 3.4"
    ]
)

==> admin_scripts-0.3.21.tar.gz: admin_scripts-0.3.21/setup.py <==
#!/usr/bin/python
# -*- coding: utf-8 -*-

# Hive Administration Scripts
# Copyright (c) 2008-2016 Hive Solutions Lda.
#
# This file is part of Hive Administration Scripts.
#
# Hive Administration Scripts is free software: you can redistribute it and/or modify
# it under the terms of the Apache License as published by the Apache
# Foundation, either version 2.0 of the License, or (at your option) any
# later version.
#
# Hive Administration Scripts is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# Apache License for more details.
#
# You should have received a copy of the Apache License along with
# Hive Administration Scripts. If not, see <http://www.apache.org/licenses/>.

__author__ = "João Magalhães <joamag@hive.pt>"
""" The author(s) of the module """

__version__ = "1.0.0"
""" The version of the module """

__revision__ = "$LastChangedRevision$"
""" The revision number of the module """

__date__ = "$LastChangedDate$"
""" The last change date of the module """

__copyright__ = "Copyright (c) 2008-2016 Hive Solutions Lda."
""" The copyright for the module """

__license__ = "Apache License, Version 2.0"
""" The license for the module """

import os
import setuptools

setuptools.setup(
    name = "admin_scripts",
    version = "0.3.21",
    author = "Hive Solutions Lda.",
    author_email = "development@hive.pt",
    description = "Administration Scripts",
    license = "Apache License, Version 2.0",
    keywords = "scripts admin public",
    url = "http://admin_scripts.hive.pt",
    zip_safe = False,
    packages = [
        "admin_scripts",
        "admin_scripts.base",
        "admin_scripts.config",
        "admin_scripts.config.development",
        "admin_scripts.extra",
        "admin_scripts.test"
    ],
    test_suite = "admin_scripts.test",
    package_dir = {
        "" : os.path.normpath("src")
    },
    package_data = {
        "admin_scripts" : [
            "config/extra/*"
        ]
    },
    entry_points = {
        "console_scripts" : [
            "cleanup = admin_scripts.base.cleanup:run"
        ]
    },
    install_requires = [
        "legacy",
        "pep8",
        "jsbeautifier"
    ],
    classifiers = [
        "Development Status :: 5 - Production/Stable",
        "Topic :: Utilities",
        "License :: OSI Approved :: Apache Software License",
        "Operating System :: OS Independent",
        "Programming Language :: Python",
        "Programming Language :: Python :: 2.6",
        "Programming Language :: Python :: 2.7",
        "Programming Language :: Python :: 3.0",
        "Programming Language :: Python :: 3.1",
        "Programming Language :: Python :: 3.2",
        "Programming Language :: Python :: 3.3",
        "Programming Language :: Python :: 3.4",
        "Programming Language :: Python :: 3.5"
    ]
)
